==> aliyun-python-sdk-scdn-1.1.0.tar.gz: aliyun-python-sdk-scdn-1.1.0/aliyunsdkscdn/request/v20171115/RefreshScdnObjectCachesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class RefreshScdnObjectCachesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'scdn', '2017-11-15', 'RefreshScdnObjectCaches')

	def get_SecurityToken(self):
		return self.get_query_params().get('SecurityToken')

	def set_SecurityToken(self,SecurityToken):
		self.add_query_param('SecurityToken',SecurityToken)

	def get_ObjectPath(self):
		return self.get_query_params().get('ObjectPath')

	def set_ObjectPath(self,ObjectPath):
		self.add_query_param('ObjectPath',ObjectPath)

	def get_OwnerId(self):
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self,OwnerId):
		self.add_query_param('OwnerId',OwnerId)

	def get_ObjectType(self):
		return self.get_query_params().get('ObjectType')

	def set_ObjectType(self,ObjectType):
		self.add_query_param('ObjectType',ObjectType)

==> aliyun-python-sdk-scdn-2.2.3.tar.gz: aliyun-python-sdk-scdn-2.2.3/aliyunsdkscdn/request/v20171115/RefreshScdnObjectCachesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkscdn.endpoint import endpoint_data

class RefreshScdnObjectCachesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'scdn', '2017-11-15', 'RefreshScdnObjectCaches')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ObjectPath(self):
		return self.get_query_params().get('ObjectPath')

	def set_ObjectPath(self,ObjectPath):
		self.add_query_param('ObjectPath',ObjectPath)

	def get_OwnerId(self):
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self,OwnerId):
		self.add_query_param('OwnerId',OwnerId)

	def get_SecurityToken(self):
		return self.get_query_params().get('SecurityToken')

	def set_SecurityToken(self,SecurityToken):
		self.add_query_param('SecurityToken',SecurityToken)

	def get_ObjectType(self):
		return self.get_query_params().get('ObjectType')

	def set_ObjectType(self,ObjectType):
		self.add_query_param('ObjectType',ObjectType)
